==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/users/language/hr.php <==
<?php

﻿;
$l['name'] = 'Korisnici';
$l['description'] = 'Administratorski modul. Upravljanje sa korisnicima programa.';
$l['deletePrimaryAdmin'] = 'Ne možete obrisati primarnog administratora';
$l['deleteYourself'] = 'Ne možete obrisati sebe';
$lang['link_type'][8]=$us_user = 'Korisnik';
$l['error_username']='Imate nedopuštene znakove u korisničkom imenu';
$l['error_username_exists']='Žao nam je, korisnik sa tim korisničkim imenom već postoji';
$l['error_email_exists']='Žao nam je, ta e-mail adresa je već registrirana u programu.';
$l['error_match_pass']='Lozinke nisu jednake';
$l['error_email']='Unjeli ste pogrešnu e-mail adresu';
$l['error_user']='Korisnika nije moguće napraviti';
$l['imported']='Uvezeno %s korisnika';
$l['failed']='Nije uspjelo';
$l['incorrectFormat']='Datoteka nije u ispravnom CSV formatu';
$l['register_email_subject']='Detalji vašeg {product_name} računa';
$l['register_email_body']='{product_name} račun je kreiran za vas na {url}
Podaci za prijavu su:
Korisničko ime: {username};
Lozinka: {password}';
$l['max_users_reached']='Dosegnut je maksimalan broj korisnika za ovaj sistem.';﻿;
$l["cmdCheckColumnRead"]= 'Koristi';
$l["cmdCheckColumnWrite"]= 'Upravljaj';
$l["cmdHeaderColumnName"]= 'Ime modula';
$l["cmdHeaderGridUserHasAccess"]= 'Korisnik ima pristup';
$l["userIsMemberOf"]= 'Korisnik je član';
$l["userVisibleTo"]= 'Korisnik je vidljiv';
$l["cmdPanelPersonal"]= 'Osobno';
$l["cmdPanelPassword"]= 'Lozinka';
$l["cmdPanelCompany"]= 'Tvrtka';
$l["cmdPanelPermissions"]= 'Dozvole';
$l["cmdPanelLogin"]= 'Prijava';
$l["cmdPanelLookFeel"]= 'Izgled & Dojam';
$l["cmdPanelSettings"]= 'Postavke';
$l["cmdPanelEnabledMail"]= 'E-mail za novo odobrene korisnike';
$l["cmdPanelDisabledMail"]= 'E-mail za novo onemogućene korisnike';
$l["cmdFieldSetPersonal"]= 'Osobno';	;
$l["cmdUserWindowTitle"]= 'Uredi korisnika';
$l["cmdNotificationWindowTitle"]= 'Uredi e-mail pozivnicu za korisnike';
$l["cmdMaskSaving"]= 'Spremam';
$l["cmdFormLabelSubject"]= 'Predmet';
$l["cmdFormLabelUsername"]= 'Korisničko ime';
$l["cmdFormLabelName"]= 'Ime';
$l["cmdFormLabelPassword"]= 'Lozinka';
$l["cmdFormLabelConfirm"]= 'Potvrdi';
$l["cmdBoxLabelEnabled"]= 'Omogući';
$l["cmdFormLabelHomepage"]= 'Početna stranica';
$l["cmdFormLabelRegistrationTime"]= 'Vrijeme registracije';
$l["cmdFormLabelLastLogin"]= 'Zadnja prijava';
$l["cmdFormLabelTotalLogins"]= 'Ukupno prijava';
$l["numberOfLogins"]= 'Broj prijava';
$l["cmdFormLabelTheme"]= 'Tema';
$l["cmdFormLabelStartModule"]= 'Početni modul';
$l["cmdFormLabelMaximunRows"]= 'Maksimalan broj redova u listama';
$l["cmdFormLabelSortNamesBy"]= 'Sortiraj imena po';
$l["cmdFormLabelLanguage"]= 'Jezik';
$l["cmdFormLabelTimezone"]= 'Vremenska zona';
$l["cmdFormLabelAdjustDaylight"]= 'Automatski prilagodi vrijeme Ljetnom/Zimskom računanju vremena';
$l["cmdFormLabelDateFormat"]= 'Format datuma';
$l["cmdFormLabelDateSeperator"]= 'Razdjelnik datuma';
$l["timeFormat"]= 'Format vremena';
$l["cmdFormLabelFirstWeekday"]= 'Prvi dan tjedna';
$l["cmdFormLabelThousandSeperator"]= 'Razdjelnik tisućica';
$l["cmdFormLabelDecimalSeperator"]= 'Decimalni razdjelnik';
$l["cmdFormLabelCurrency"]= 'Valuta';
$l["account"]= 'Račun';
$l["confirmPassword"]= 'Potvrdi lozinku';
$l["companyProfile"]= 'Profil tvrtke';
$l["loginInfo"]= 'Podaci za prijavu';
$l["changePassword"]= 'Promjeni lozinku';
$l["currentPassword"]= 'Trenutna lozinka';
$l["newPassword"]= 'Nova lozinka';
$l["confirmPassword"]= 'Potvrdi lozinku';
$l["moduleAccess"]= 'Pristup modulu';
$l["groupMembership"]= 'Članstvo u grupi';
$l["personalProfile"]= 'Osobni profil';
$l["settings"]= 'Osobne postavke';
$l["dmy"]= 'Dan-Mjesec-Godina';
$l["mdy"]= 'Mjesec-Dan-Godina';
$l["jmd"]= 'Godina-Mjesec-Dan';
$l["fullhourformat"]= '24 satni format';
$l["halfhourformat"]= '12 satni format';
$l["sunday"]= 'Nedjelja';
$l["monday"]= 'Ponedjeljak';
$l["regionalSettings"]= 'Regionalne postavke';
$l["userSettings"]= 'Korisničke postavke';
$l["profile"]='Profil';
$l["maxUsersReached"]='Dosegnut je maksimalan broj korisnika. Kontaktirajte svoga pružatelja usluge kako bi povećali maksimalan broj korisnika.';
$l["group"]='Grupa';
$l["muteSound"]='Isključi zvuk';
$l["mailReminders"]='Podsjetnici za poštu';
$l["downloadSampleCSV"]='Skini uzorak CSV datoteke';
$l["importText"]='Možete uvesti korisnike koristeći CSV datoteku. Kako bi znali kako CSV datoteka treba biti formatirana skinite uzorak datoteke.<br />Prva linija mora sadržavati nazive stupaca. Slijedeća polja su obavezna za svakog korisnika:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]= 'Koristi';
$l["manageModule"]= 'Upravljaj';
$l["numberFormat"]='Brojčani format';
$l["importExport"]='Uvezi / Izvezi';
$l["listSeparator"]='Razdjelnik liste';
$l["textSeparator"]='Razdjelnik teksta';
$l["deleteWarning"]='UPOZORENJE!!! Svi korisnički podaci uključujući adresare, projekte, kalendare itd. će biti obrisani!';
$l["lastName"]= 'Prezime';
$l["firstName"]= 'Ime';
$l["sendInvitation"]='Pošalji pozivnicu';
$l["contactInfo"]='Kontakt info';
$l["popupNotification"]='Prikaži iskočni prozor za podsjetnike ili nove e-mail poruke';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/users/language/hr.php <==
<?php

$l['name'] = 'Korisnici';
$l['description'] = 'Administratorski modul. Upravljanje sa korisnicima programa.';
$l['deletePrimaryAdmin'] = 'Ne možete obrisati primarnog administratora';
$l['deleteYourself'] = 'Ne možete obrisati sebe';
$lang['link_type'][8]=$us_user = 'Korisnik';
$l['error_username']='Imate nedopuštene znakove u korisničkom imenu';
$l['error_username_exists']='Žao nam je, korisnik sa tim korisničkim imenom već postoji';
$l['error_email_exists']='Adresa e-pošte je već registrirana u programu.';
$l['error_match_pass']='Lozinke nisu jednake';
$l['error_email']='Unjeli ste pogrešnu adresu e-pošte';
$l['error_user']='Korisnika nije moguće napraviti';
$l['imported']='Uvezeno %s korisnika';
$l['failed']='Nije uspjelo';
$l['incorrectFormat']='Datoteka nije u ispravnom CSV formatu';
$l['register_email_subject']='Detalji vašeg {product_name} računa';
$l['register_email_body']='{product_name} račun je stvoren za vas na {url}
Podaci za prijavu su:
Korisničko ime: {username};
Lozinka: {password}';
$l['max_users_reached']='Dosegnut je maksimalan broj korisnika za ovaj sustav.';;
$l["cmdCheckColumnRead"]= 'Koristi';
$l["cmdCheckColumnWrite"]= 'Upravljaj';
$l["cmdHeaderColumnName"]= 'Ime modula';
$l["cmdHeaderGridUserHasAccess"]= 'Korisnik ima pristup';
$l["userIsMemberOf"]= 'Korisnik je član';
$l["userVisibleTo"]= 'Korisnik je vidljiv';
$l["cmdPanelPersonal"]= 'Osobno';
$l["cmdPanelPassword"]= 'Lozinka';
$l["cmdPanelCompany"]= 'Tvrtka';
$l["cmdPanelPermissions"]= 'Dozvole';
$l["cmdPanelLogin"]= 'Prijava';
$l["cmdPanelLookFeel"]= 'Izgled & Dojam';
$l["cmdPanelSettings"]= 'Postavke';
$l["cmdPanelEnabledMail"]= 'E-pošta za novo odobrene korisnike';
$l["cmdPanelDisabledMail"]= 'E-pošta za novo onemogućene korisnike';
$l["cmdFieldSetPersonal"]= 'Osobno';	;
$l["cmdUserWindowTitle"]= 'Uredi korisnika';
$l["cmdNotificationWindowTitle"]= 'Uredi pozivnicu e-pošte za korisnike';
$l["cmdMaskSaving"]= 'Spremam';
$l["cmdFormLabelSubject"]= 'Predmet';
$l["cmdFormLabelUsername"]= 'Korisničko ime';
$l["cmdFormLabelName"]= 'Ime';
$l["cmdFormLabelPassword"]= 'Lozinka';
$l["cmdFormLabelConfirm"]= 'Potvrdi';
$l["cmdBoxLabelEnabled"]= 'Omogući';
$l["cmdFormLabelHomepage"]= 'Početna stranica';
$l["cmdFormLabelRegistrationTime"]= 'Vrijeme registracije';
$l["cmdFormLabelLastLogin"]= 'Zadnja prijava';
$l["cmdFormLabelTotalLogins"]= 'Ukupno prijava';
$l["numberOfLogins"]= 'Broj prijava';
$l["cmdFormLabelTheme"]= 'Tema';
$l["cmdFormLabelStartModule"]= 'Početni modul';
$l["cmdFormLabelMaximunRows"]= 'Maksimalan broj redova u listama';
$l["cmdFormLabelSortNamesBy"]= 'Sortiraj imena po';
$l["cmdFormLabelLanguage"]= 'Jezik';
$l["cmdFormLabelTimezone"]= 'Vremenska zona';
$l["cmdFormLabelAdjustDaylight"]= 'Automatski prilagodi vrijeme Ljetnom/Zimskom računanju vremena';
$l["cmdFormLabelDateFormat"]= 'Format datuma';
$l["cmdFormLabelDateSeperator"]= 'Razdjelnik datuma';
$l["timeFormat"]= 'Format vremena';
$l["cmdFormLabelFirstWeekday"]= 'Prvi dan tjedna';
$l["cmdFormLabelThousandSeperator"]= 'Razdjelnik tisućica';
$l["cmdFormLabelDecimalSeperator"]= 'Decimalni razdjelnik';
$l["cmdFormLabelCurrency"]= 'Valuta';
$l["account"]= 'Račun';
$l["confirmPassword"]= 'Potvrdi lozinku';
$l["companyProfile"]= 'Profil tvrtke';
$l["loginInfo"]= 'Podaci za prijavu';
$l["changePassword"]= 'Promjeni lozinku';
$l["currentPassword"]= 'Trenutna lozinka';
$l["newPassword"]= 'Nova lozinka';
$l["confirmPassword"]= 'Potvrdi lozinku';
$l["moduleAccess"]= 'Pristup modulu';
$l["groupMembership"]= 'Članstvo u grupi';
$l["personalProfile"]= 'Osobni profil';
$l["settings"]= 'Osobne postavke';
$l["dmy"]= 'Dan-Mjesec-Godina';
$l["mdy"]= 'Mjesec-Dan-Godina';
$l["jmd"]= 'Godina-Mjesec-Dan';
$l["fullhourformat"]= '24 satni format';
$l["halfhourformat"]= '12 satni format';
$l["sunday"]= 'Nedjelja';
$l["monday"]= 'Ponedjeljak';
$l["regionalSettings"]= 'Regionalne postavke';
$l["userSettings"]= 'Korisničke postavke';
$l["profile"]='Profil';
$l["maxUsersReached"]='Dosegnut je maksimalan broj korisnika. Kontaktirajte svoga pružatelja usluge kako biste povećali maksimalan broj korisnika.';
$l["group"]='Grupa';
$l["muteSound"]='Isključi zvuk';
$l["mailReminders"]='Podsjetnici za poštu';
$l["downloadSampleCSV"]='Preuzmi uzorak CSV datoteke';
$l["importText"]='Možete uvesti korisnike koristeći CSV datoteku. Kako biste znali kako CSV datoteka treba biti formatirana preuzmite uzorak datoteke.<br />Prvi red mora sadržavati nazive stupaca. Sljedeća polja su obavezna za svakog korisnika:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]= 'Koristi';
$l["manageModule"]= 'Upravljaj';
$l["numberFormat"]='Brojčani format';
$l["importExport"]='Uvoz / Izvoz';
$l["listSeparator"]='Razdjelnik liste';
$l["textSeparator"]='Razdjelnik teksta';
$l["deleteWarning"]='UPOZORENJE!!! Svi korisnički podaci uključujući adresare, projekte, kalendare itd. će biti obrisani!';
$l["lastName"]= 'Prezime';
$l["firstName"]= 'Ime';
$l["sendInvitation"]='Pošalji pozivnicu';
$l["contactInfo"]='Kontakt info';
$l["popupNotification"]='Prikaži iskočni prozor za podsjetnike ili nove poruke e-pošte';

$l["muteNewMailSound"]='Isključi zvuk nove e-pošte';
$l["muteReminderSound"]='Isključi zvuk podsjetnika';
$l["showSmilies"]='Prikaži smješke';
$l['dashdmy']='Dan-Mjesec-Godina';
$l['slashmdy']='Mjesec/Dan/Godina';
$l['dotdmy']='Dan.Mjesec.Godina';
$l['slashdmy']='Dan/Mjesec/Godina';
$l['generatePassword']='Generiraj lozinku';
$l['generatedPasswordIs']='Generirana lozinka je';
$l['openContact']='Otvori kontakt';
$l['showProUsers']='Prikaži pro korisnike';
$l['updateExistingOnImport']='Ažuriraj postojeće korisnike (po korisničkom imenu)';
